==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPRedirectPortFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPRedirectPortFluent<A extends HTTPRedirectPortFluent<A>> extends BaseFluent<A>{
  public HTTPRedirectPortFluent() {
  }
  public HTTPRedirectPortFluent(HTTPRedirectPort instance) {
    instance = (instance != null ? instance : new HTTPRedirectPort());

    if (instance != null) {
      this.withPort(instance.getPort());
      this.withPort(instance.getPort());
    }
  }
  private Integer port;
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public boolean hasPort() {
    return this.port != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPRedirectPortFluent that = (HTTPRedirectPortFluent) o;
    if (!java.util.Objects.equals(port, that.port)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(port,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (port != null) { sb.append("port:"); sb.append(port); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPRedirectPortFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HTTPRedirectPortFluent<A extends HTTPRedirectPortFluent<A>> extends BaseFluent<A>{
  public HTTPRedirectPortFluent() {
  }
  
  public HTTPRedirectPortFluent(HTTPRedirectPort instance) {
    this.copyInstance(instance);
  }
  private Integer port;
  
  protected void copyInstance(HTTPRedirectPort instance) {
    instance = (instance != null ? instance : new HTTPRedirectPort());
  
    if (instance != null) {
        this.withPort(instance.getPort());
        this.withPort(instance.getPort());
      }
  }
  
  public Integer getPort() {
    return this.port;
  }
  
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  
  public boolean hasPort() {
    return this.port != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPRedirectPortFluent that = (HTTPRedirectPortFluent) o;
    if (!java.util.Objects.equals(port, that.port)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(port,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (port != null) { sb.append("port:"); sb.append(port); }
    sb.append("}");
    return sb.toString();
  }
  

}
